kibitzr package
===============

Subpackages
-----------

.. toctree::

    kibitzr.fetcher
    kibitzr.notifier
    kibitzr.transformer

Submodules
----------

kibitzr.bash module
-------------------

.. automodule:: kibitzr.bash
    :members:
    :undoc-members:
    :show-inheritance:

kibitzr.bootstrap module
------------------------

.. automodule:: kibitzr.bootstrap
    :members:
    :undoc-members:
    :show-inheritance:

kibitzr.checker module
----------------------

.. automodule:: kibitzr.checker
    :members:
    :undoc-members:
    :show-inheritance:

kibitzr.cli module
------------------

.. automodule:: kibitzr.cli
    :members:
    :undoc-members:
    :show-inheritance:

kibitzr.conf module
-------------------

.. automodule:: kibitzr.conf
    :members:
    :undoc-members:
    :show-inheritance:

kibitzr.main module
-------------------

.. automodule:: kibitzr.main
    :members:
    :undoc-members:
    :show-inheritance:

kibitzr.storage module
----------------------

.. automodule:: kibitzr.storage
    :members:
    :undoc-members:
    :show-inheritance:

kibitzr.utils module
--------------------

.. automodule:: kibitzr.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: kibitzr
    :members:
    :undoc-members:
    :show-inheritance:
